#!

1. 目录结构
.
├── bin
│   └── bin-upload-pypi
├── build
│   ├── bdist.linux-x86_64
│   └── lib
│       └── ivystar
│           ├── __init__.py
│           └── main.py
├── dist
│   ├── ivystar-0.0.2-py3-none-any.whl
│   └── ivystar-0.0.2.tar.gz
├── ivystar
│   ├── __init__.py
│   ├── main.py
│   └── src
│       ├── algorithm
│       ├── conf
│       ├── dataio
│       ├── model
│       ├── utils
│       └── web
├── ivystar.egg-info
│   ├── dependency_links.txt
│   ├── entry_points.txt
│   ├── PKG-INFO
│   ├── requires.txt
│   ├── SOURCES.txt
│   └── top_level.txt
├── LICENSE.txt
├── README.rst
└── setup.py

15 directories, 16 files
